@@ -3,12 +3,6 @@ require 'delayed/compatibility'
 require 'delayed/exceptions'
 require 'delayed/message_sending'
 require 'delayed/performable_method'
-
-if defined?(ActionMailer)
-  require 'action_mailer/version'
-  require 'delayed/performable_mailer'
-end
-
 require 'delayed/yaml_ext'
 require 'delayed/lifecycle'
 require 'delayed/plugin'
@@ -19,5 +13,14 @@ require 'delayed/worker'
 require 'delayed/deserialization_error'
 require 'delayed/railtie' if defined?(Rails::Railtie)
 
+ActiveSupport.on_load(:action_mailer) do
+  require 'delayed/performable_mailer'
+  ActionMailer::Base.extend(Delayed::DelayMail)
+end
+
+module Delayed
+  autoload :PerformableMailer, 'delayed/performable_mailer'
+end
+
 Object.send(:include, Delayed::MessageSending)
 Module.send(:include, Delayed::MessageSendingClassMethods)
